# starpolymers

Star Polymers is a Python Library used for generating LAMMPS input files and analysing LAMMPS output files, in dump formats and other formats. Additionally, there are scripts used for interacting with Colvars input/output files.

## Installation

Clone this repository to a Python path

```
git clone https://github.com/debeshmandal/starpolymers
```

## Usage

Examples:

```
import starpolymers
from starpolymers.star_gen2 import FileGenerator
from starpolymers.pmf import PMF
```
